from importFromParent import importFromParent


def test(string: str, start = 'TEST:', space_after_start: bool = True, not_string: dict = {'before':'', 'after':'', 'both':'"'}, end='.'):
    space = notMS1 = notMS2 = ''
    if space_after_start:
        space = ' '
    if not_string['before'] != not_string['after']:
        if not_string['both'] == '':
            raise Exception('''if "before" and "after" are different, "both" can not be <@void/@nothing/""/''>!''')
        else:
            notMS1 = notMS2 = not_string['both']
    else:
        if not_string['both'] != '':
            if not_string['after'] == '':
                notMS1 = notMS2 = not_string['both']
            else:
                raise Exception('''if "before" and "after" are equal and different of <@void/@nothing/""/''>!, "both" can only be <@void/@nothing/""/''>!''')
        else:
            notMS1 = notMS2 = not_string['after']
    print(f'{start}{space}{notMS1}{string}{notMS2}{end}')



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="cau_utilities",
    version="0.0.0.1",
    author="Cauã S. C. P.",
    author_email="cauascp37@gmail.com",
    description="this project has a lot of utilities made by Caua_SCP.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://www.youtube.com/channel/UCAbwAklWIeuoKKjVBMQVCew",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6'
    ,
    install_requires=[
        'importFromParent',
    ]
    ,
    zip_safe=False
)
